==> gazie7.30.zip: gazie/modules/contab/menu.italian.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['contab'] = array('name' => "Contabilit&agrave;",
    'title' => "Gestione Prima Nota e I.V.A.",
    'm2' => array(1 => array("Prima nota, inserimento, modifica, eliminazione dei movimenti contabili ed I.V.A.", "Prima Nota"),
        2 => array("Gestione del Piano dei Conti", "Piano dei conti"),
        3 => array("Gestione dell'Archivio delle Causali Contabili", "Causali Contabili"),
        4 => array("Visualizzazione e stampa dei registri I.V.A.", "Registri IVA"),
        5 => array("Preparazione file per Comunicazioni dati", "Comunicazioni dati"),
        6 => array("Visualizzazione e stampa del Libro Giornale", "Libro Giornale"),
        7 => array("Visualizzazione e stampa della situazione contabile", "Situazione contabile"),
    ),
    'm3' => array(1 => array("Inserisci un nuovo movimento contabile", "Nuovo movimento contabile"),
        2 => array("Inserisci un nuovo conto", "Nuovo conto"),
        3 => array("Visualizzazione e stampa dei partitari", "Visualizza/stampa partitari"),
        4 => array("Inserisci un nuova causale contabile", "Nuova causale contabile"),
        5 => array("Stampa il piano dei conti", "Stampa Piano dei Conti"),
        6 => array("Visualizzazione e stampa di estratti conto o partite aperte", "Estratti Conto/Partite Aperte"),
        7 => array("Visualizzazione e stampa di dare/avere clienti/fornitori", "Analisi Debiti/Crediti"),
        8 => array("Comunicazione liquidazioni IVA", "Comunicazione liquidazioni IVA"),
        9 => array("File XML per Comunicazioni liquidazioni IVA", "Lista File Comunicazioni liquidazioni IVA"),
        10 => array("File XML per Comunicazione dati fatture", "Comunicazione dati fatture"),
        11 => array("Visualizzazione e stampa del registro riepilogativo I.V.A.", "Liquidazione IVA"),
        12 => array("File XML per Comunicazioni dati fatture", "Lista File Comunicazioni dati fatture"),
        13 => array( "Visualizza registro corrispettivi giornalieri", "Registro Corrispettivi"),
        14 => array( "Files XML per Comunicazioni dati fatture da e verso stranieri", "Esterometro")
    )
);
?>

==> gazie8.00.zip: gazie/modules/contab/menu.italian.php <==
<?php
/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['contab'] = array('name' => "Contabilit&agrave;",
    'title' => "Gestione Prima Nota e I.V.A.",
    'm2' => array(1 => array("Prima nota, inserimento, modifica, eliminazione dei movimenti contabili ed I.V.A.", "Prima Nota"),
        2 => array("Gestione del Piano dei Conti", "Piano dei conti"),
        3 => array("Gestione dell'Archivio delle Causali Contabili", "Causali Contabili"),
        4 => array("Visualizzazione e stampa dei registri I.V.A.", "Registri IVA"),
        5 => array("Preparazione file per Comunicazioni dati", "Comunicazioni dati"),
        6 => array("Visualizzazione e stampa del Libro Giornale", "Libro Giornale"),
        7 => array("Visualizzazione e stampa della situazione contabile", "Situazione contabile"),
    ),
    'm3' => array(1 => array("Inserisci un nuovo movimento contabile", "Nuovo movimento contabile"),
        2 => array("Inserisci un nuovo conto", "Nuovo conto"),
        3 => array("Visualizzazione e stampa dei partitari", "Visualizza/stampa partitari"),
        4 => array("Inserisci un nuova causale contabile", "Nuova causale contabile"),
        5 => array("Stampa il piano dei conti", "Stampa Piano dei Conti"),
        6 => array("Visualizzazione e stampa di estratti conto o partite aperte", "Estratti Conto/Partite Aperte"),
        7 => array("Visualizzazione e stampa di dare/avere clienti/fornitori", "Analisi Debiti/Crediti"),
        8 => array("Comunicazione liquidazioni IVA", "Comunicazione liquidazioni IVA"),
        9 => array("File XML per Comunicazioni liquidazioni IVA", "Lista File Comunicazioni liquidazioni IVA"),
        10 => array("File XML per Comunicazione dati fatture", "Comunicazione dati fatture"),
        11 => array("Visualizzazione e stampa del registro riepilogativo I.V.A.", "Liquidazione IVA"),
        12 => array("File XML per Comunicazioni dati fatture", "Lista File Comunicazioni dati fatture"),
        13 => array( "Visualizza registro corrispettivi giornalieri", "Registro Corrispettivi"),
        14 => array( "Files XML per Comunicazioni dati fatture da e verso stranieri", "Esterometro"),
        15 => array( "Riconciliazione E/C bancario", "Riconciliazione E/C")
    )
);
?>
